==> fuml-1.2.1-test-sources.jar: org/modeldriven/fuml/test/load/profile/Namespace.java <==
/*
 * Initial version copyright 2008 Lockheed Martin Corporation, except
 * as stated in the file entitled Licensing-Information.
 *
 * Modifications:
 * Copyright 2009 Data Access Technologies, Inc.
 * Copyright 2013 Ivar Jacobson International SA
 *
 * Licensed under the Academic Free License version 3.0
 * (http://www.opensource.org/licenses/afl-3.0.php), except as stated
 * in the file entitled Licensing-Information.
 *
 * Contributors:
 *   MDS - initial API and implementation
 *   IJI
 *
 */
package org.modeldriven.fuml.test.load.profile;

import org.modeldriven.fuml.repository.ext.Stereotype;

/**
 * 
 * This stereotype tags or annotates a UML package as a namespace.
 * 
 */
public class Namespace extends Stereotype

{

	public static final String BASE__PACKAGE = "base_Package";
	/**
	 * The namespace URI used to reference all SDO Types contained within the
	 * UML package, and the namespace URI used link or map this UML package to
	 * SDO namespace specific configuration information.
	 */
	public static final String URI = "uri";

	private fUML.Syntax.Classes.Kernel.Package base_Package;
	/**
	 * The namespace URI used to reference all SDO Types contained within the
	 * UML package, and the namespace URI used link or map this UML package to
	 * SDO namespace specific configuration information.
	 */
	private String uri;

	public fUML.Syntax.Classes.Kernel.Package getBase_Package() {
		return this.base_Package;
	}

	public void setBase_Package(fUML.Syntax.Classes.Kernel.Package value) {
		this.base_Package = value;
	}

	public String getUri() {
		return this.uri;
	}

	public void setUri(String value) {
		this.uri = value;
	}
}

==> fuml-1.4.0-test-sources.jar: org/modeldriven/fuml/test/load/profile/Namespace.java <==
/*
 * Initial version copyright 2008 Lockheed Martin Corporation, except
 * as stated in the file entitled Licensing-Information.
 *
 * Modifications:
 * Copyright 2009 Data Access Technologies, Inc.
 * Copyright 2013 Ivar Jacobson International SA
 *
 * Licensed under the Academic Free License version 3.0
 * (http://www.opensource.org/licenses/afl-3.0.php), except as stated
 * in the file entitled Licensing-Information.
 *
 * Contributors:
 *   MDS - initial API and implementation
 *   IJI
 *
 */
package org.modeldriven.fuml.test.load.profile;

import org.modeldriven.fuml.repository.ext.Stereotype;

/**
 * 
 * This stereotype tags or annotates a UML package as a namespace.
 * 
 */
public class Namespace extends Stereotype

{

	public static final String BASE__PACKAGE = "base_Package";
	/**
	 * The namespace URI used to reference all SDO Types contained within the
	 * UML package, and the namespace URI used link or map this UML package to
	 * SDO namespace specific configuration information.
	 */
	public static final String URI = "uri";

	private fuml.syntax.packages.Package base_Package;
	/**
	 * The namespace URI used to reference all SDO Types contained within the
	 * UML package, and the namespace URI used link or map this UML package to
	 * SDO namespace specific configuration information.
	 */
	private String uri;

	public fuml.syntax.packages.Package getBase_Package() {
		return this.base_Package;
	}

	public void setBase_Package(fuml.syntax.packages.Package value) {
		this.base_Package = value;
	}

	public String getUri() {
		return this.uri;
	}

	public void setUri(String value) {
		this.uri = value;
	}
}
